@@ -264,39 +264,6 @@ void gok_spy_accessible_unref(Accessible* accessible)
 	gok_log_leave ();
 }
 
-extern SPIBoolean cspi_accessible_is_a (Accessible *accessible, const char *interface_name);
-
-gboolean gok_spy_accessible_is_okay(Accessible* accessible)
-{
-	gboolean returncode = FALSE;
-	gok_log_enter();
-	if (accessible != NULL) 
-	{
-		/* FIXME: we should have a better way of doing this! */
-		returncode = cspi_accessible_is_a (accessible, "IDL:Accessibility/Accessible:1.0");
-		/*
-		if (Accessible_isApplication(accessible) ||
-		    Accessible_isComponent(accessible))
-		{
-			returncode = TRUE;
-		}
-		*/
-			/*
-	    	if (gok_spy_accessible_is_desktopChild(accessible) == FALSE)
-	    	{
-				accessible = NULL;
-			}
-			else
-			{
-				returncode = TRUE;
-			}
-			*/
-	}
-	gok_log("returning: %d",returncode);
-	gok_log_leave();
-	return returncode;
-}
-
 static gboolean
 gok_spy_idle_handler (gpointer data)
 {
@@ -1398,17 +1365,12 @@ gok_spy_distinguish_node_name (AccessibleNode *node)
 						/* don't prepend if we've already used this label as GokButton name */
 						if (s != NULL && strcmp (s, node->pname)) {
 							if ( strlen (s) != 0 )  {
-								gchar buffer[64] = "";
-								if (node->pname) 
-								{
-									if (strlen (node->pname)) 
-									{
-										strncpy (buffer, node->pname, 63);
-									}
-									g_free (node->pname); 
-								}
-								buffer[63] = '\0'; /* ensure null termination */
-								node->pname = g_strconcat (s, " ", buffer, NULL);
+								gchar *tmp;
+								
+								tmp = node->pname;
+								node->pname = g_strconcat (s, " ", tmp, NULL);
+								g_free (tmp);
+								
 								SPI_freeString (s);
 								Accessible_unref (labelAccessible);
 								distinguished = TRUE;
@@ -1440,7 +1402,7 @@ static gboolean resolve_namesakes_reentry_guard = FALSE;
 static void
 gok_spy_resolve_namesakes (GSList *list)
 {
-	gchar name[64]; /* names longer than this will not be resolved */
+	gchar *name;
 	GSList *namesake;
 	gboolean distinguished_source = FALSE;
 
@@ -1456,12 +1418,14 @@ gok_spy_resolve_namesakes (GSList *list)
 	while (list && list->next) {
 		AccessibleNode *node = list->data;
 		GSList *lp = list;
+
 		if (node && node->pname) 
-		{
-		    strncpy (name, node->pname, 63);
-		}
+		    name = g_strdup (node->pname);
+		else
+		    name = g_strdup ("");
+		    
 		/* for every node with the same name as the current node... */
-		while (lp && (namesake = gok_spy_node_get_node_named ( lp->next, name )) 
+		while (lp && (namesake = gok_spy_node_get_node_named (lp->next, name)) 
 				!= NULL) 
 		{
 			if (!distinguished_source) {
@@ -1473,6 +1437,7 @@ gok_spy_resolve_namesakes (GSList *list)
 		}
 		distinguished_source = FALSE;	
 		if (list) list = list->next;
+		g_free (name);
 	}
 
 	resolve_namesakes_reentry_guard = FALSE;
